@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
@@ -117,11 +118,13 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -295,6 +298,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::LocalGatewayRoute",
@@ -479,7 +483,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -650,6 +656,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -966,9 +973,11 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -996,11 +1005,13 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
@@ -1033,7 +1044,6 @@ cached: list[str] = [
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distributiontenant.json",
-    "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
     "aws-cloudfront-monitoringsubscription.json",
@@ -1162,6 +1172,7 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-localgatewayroute.json",
@@ -1245,7 +1256,6 @@ cached: list[str] = [
     "aws-ecs-capacityprovider.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1340,7 +1350,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1387,16 +1399,17 @@ cached: list[str] = [
     "aws-lakeformation-resource.json",
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
-    "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
+    "aws-lambda-permission.json",
     "aws-lambda-url.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -1489,10 +1502,12 @@ cached: list[str] = [
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -1549,8 +1564,10 @@ cached: list[str] = [
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-s3tables-tablepolicy.json",
+    "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
+    "aws-sagemaker-domain.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1647,6 +1664,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
+    "aws-synthetics-canary.json",
     "aws-systemsmanagersap-application.json",
     "aws-timestream-influxdbinstance.json",
     "aws-transfer-agreement.json",
