@@ -107,11 +107,13 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -418,6 +420,7 @@ types: list[str] = [
     "AWS::Glue::Trigger",
     "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
+    "AWS::GreengrassV2::ComponentVersion",
     "AWS::GreengrassV2::Deployment",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
@@ -426,7 +429,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -456,19 +461,25 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
+    "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
     "AWS::IoT::Command",
+    "AWS::IoT::CustomMetric",
+    "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
     "AWS::IoT::FleetMetric",
     "AWS::IoT::JobTemplate",
+    "AWS::IoT::MitigationAction",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
     "AWS::IoT::ProvisioningTemplate",
     "AWS::IoT::RoleAlias",
+    "AWS::IoT::ScheduledAudit",
+    "AWS::IoT::SecurityProfile",
     "AWS::IoT::Thing",
     "AWS::IoT::ThingGroup",
     "AWS::IoT::ThingPrincipalAttachment",
@@ -613,6 +624,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -865,6 +877,7 @@ cached: list[str] = [
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
@@ -886,6 +899,7 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-capacityreservation.json",
@@ -913,11 +927,13 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
@@ -946,7 +962,6 @@ cached: list[str] = [
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distributiontenant.json",
-    "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
     "aws-cloudfront-monitoringsubscription.json",
@@ -1046,6 +1061,7 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-localgatewayroute.json",
@@ -1120,7 +1136,6 @@ cached: list[str] = [
     "aws-ecs-capacityprovider.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1199,6 +1214,7 @@ cached: list[str] = [
     "aws-glue-trigger.json",
     "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
+    "aws-greengrassv2-componentversion.json",
     "aws-greengrassv2-deployment.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
@@ -1207,7 +1223,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1236,18 +1254,24 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
     "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
     "aws-iot-command.json",
+    "aws-iot-custommetric.json",
+    "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
     "aws-iot-fleetmetric.json",
     "aws-iot-jobtemplate.json",
+    "aws-iot-mitigationaction.json",
     "aws-iot-policy.json",
     "aws-iot-provisioningtemplate.json",
     "aws-iot-rolealias.json",
+    "aws-iot-scheduledaudit.json",
+    "aws-iot-securityprofile.json",
     "aws-iot-thing.json",
     "aws-iot-thinggroup.json",
     "aws-iot-thingprincipalattachment.json",
@@ -1284,6 +1308,7 @@ cached: list[str] = [
     "aws-location-routecalculator.json",
     "aws-location-tracker.json",
     "aws-location-trackerconsumer.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -1345,6 +1370,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -1384,6 +1410,7 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -1438,8 +1465,10 @@ cached: list[str] = [
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-s3tables-tablepolicy.json",
+    "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
+    "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
